[![PyPI](https://img.shields.io/badge/PyPI-v1.1.3-blue.svg)](https://pypi.org/project/forchan/) [![GitHub](https://img.shields.io/badge/GitHub-v1.1.3-purple.svg)](https://github.com/ganelonhb/forchan)

# forchan

In this house, we check are fortunes.

## Installation

Install with pip using the command

```bash
python -m pip install forchan
```

## Usage

Enter `forchan` in a terminal to get your fortune. For a list of options, including
compatability options for terminals that support less/no color formatting, type `forchan -h`.

## Compatability Levels

* 0 - Prints with no color or formatting.
* 1 - Prints with default terminal colors only, and bold formatting.
* 2 - Prints with extended terminal colors and bold formatting.
